@@ -40,6 +40,12 @@ type version = int * int * int
 val version : unit -> version
 (** Get the installed version of nbdkit. *)
 
+val probe_server_parameter : string -> bool
+(** Probe if a particular server parameter is available.
+
+    eg. [probe_server_parameter "--name"] tests if the [--name]
+    parameter is available in this build of nbdkit. *)
+
 val probe_plugin : string -> bool
 (** Probe if a particular plugin is available. *)
 
@@ -61,12 +67,16 @@ val probe_filter_parameter : string -> string -> bool
 type cmd
 (** An nbdkit command. *)
 
-val create : ?quiet:bool -> string -> cmd
+val create : ?quiet:bool -> ?name:string -> string -> cmd
 (** Create a new nbdkit command.
 
     The parameter is the required plugin name.  Normally the nbdkit
     verbose ([-v]) flag is inherited from virt-v2v but exceptionally
-    you can use ~quiet:true to make nbdkit always quiet. *)
+    you can use ~quiet:true to make nbdkit always quiet.
+
+    The optional [?name] parameter can be used to name this
+    nbdkit instance (the name appears in debugging messages
+    if using nbdkit >= 1.46). *)
 
 val add_debug_flag : cmd -> string -> string -> unit
 val set_readonly : cmd -> bool -> unit
